==> qtah-qt5-0.3.0.tar.gz: qtah-qt5-0.3.0/src/Graphics/UI/Qtah/Widgets/QStackedWidget.hs <==
{-# LANGUAGE CPP, FlexibleContexts, FlexibleInstances, GeneralizedNewtypeDeriving, MultiParamTypeClasses, ScopedTypeVariables, TypeSynonymInstances, UndecidableInstances #-}
#if !MIN_VERSION_base(4,8,0)
{-# LANGUAGE OverlappingInstances #-}
#endif

---------- GENERATED FILE, EDITS WILL BE LOST ----------

{-# LANGUAGE NoMonomorphismRestriction #-}

module Graphics.UI.Qtah.Widgets.QStackedWidget (
  QStackedWidgetValue (..),
  QStackedWidgetConstPtr (..),
  QStackedWidgetPtr (..),
  QStackedWidgetConst,
  QStackedWidget,
  castConst,
  cast,
  downCastConst,
  downCast,
  new,
  newWithParent,
  addWidget,
  count,
  currentIndex,
  currentWidget,
  indexOf,
  insertWidget,
  removeWidget,
  setCurrentIndex,
  setCurrentWidget,
  widget,
  currentChangedSignal,
  widgetRemovedSignal,
  ) where

import Graphics.UI.Qtah.Generated.Widgets.QStackedWidget
import Graphics.UI.Qtah.Internal.Listener
import qualified Graphics.UI.Qtah.Signal as QtahSignal
import Prelude ()
import qualified Prelude as HoppyP


castConst = toQStackedWidgetConst
cast = toQStackedWidget
downCastConst = downToQStackedWidgetConst
downCast = downToQStackedWidget

currentChangedSignal :: (QStackedWidgetPtr object) => QtahSignal.Signal object (HoppyP.Int -> HoppyP.IO ())
currentChangedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerInt_new fn'
    listenerInt_connectListener listener' object' "2currentChanged(int)"
  , QtahSignal.internalName = "QStackedWidget::currentChanged (ListenerInt)"
  }

widgetRemovedSignal :: (QStackedWidgetPtr object) => QtahSignal.Signal object (HoppyP.Int -> HoppyP.IO ())
widgetRemovedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerInt_new fn'
    listenerInt_connectListener listener' object' "2widgetRemoved(int)"
  , QtahSignal.internalName = "QStackedWidget::widgetRemoved (ListenerInt)"
  }

==> qtah-qt5-0.8.0.tar.gz: qtah-qt5-0.8.0/src/Graphics/UI/Qtah/Widgets/QStackedWidget.hs <==
{-# LANGUAGE FlexibleContexts, FlexibleInstances, ForeignFunctionInterface, MonoLocalBinds, MultiParamTypeClasses, ScopedTypeVariables, TypeSynonymInstances, UndecidableInstances #-}
---------- GENERATED FILE, EDITS WILL BE LOST ----------

{-# LANGUAGE NoMonomorphismRestriction #-}

module Graphics.UI.Qtah.Widgets.QStackedWidget (
  QStackedWidgetValue (..),
  QStackedWidgetConstPtr (..),
  QStackedWidgetPtr (..),
  QStackedWidgetConst,
  QStackedWidget,
  castConst,
  cast,
  downCastConst,
  downCast,
  new,
  newWithParent,
  addWidget,
  count,
  currentIndex,
  currentWidget,
  emitCurrentChanged,
  emitWidgetRemoved,
  indexOf,
  insertWidget,
  removeWidget,
  setCurrentIndex,
  setCurrentWidget,
  widget,
  currentChangedSignal,
  widgetRemovedSignal,
  ) where

import qualified Foreign.Hoppy.Runtime as QtahFHR
import Graphics.UI.Qtah.Generated.Widgets.QStackedWidget
import Graphics.UI.Qtah.Internal.Listener
import qualified Graphics.UI.Qtah.Signal as QtahSignal
import Prelude (($), (>>))
import qualified Prelude as HoppyP
import qualified Prelude as QtahP


castConst = toQStackedWidgetConst
cast = toQStackedWidget
downCastConst = downToQStackedWidgetConst
downCast = downToQStackedWidget

currentChangedSignal :: (QStackedWidgetPtr object) => QtahSignal.Signal object (HoppyP.Int -> HoppyP.IO ())
currentChangedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerInt_new object' "2currentChanged(int)" fn'
    valid' <- listenerInt_isValid listener'
    if valid'
      then QtahP.fmap QtahP.Just $ QtahSignal.internalMakeConnection listener'
      else QtahFHR.delete listener' >> QtahP.return QtahP.Nothing
  , QtahSignal.internalName = "QStackedWidget::currentChanged (ListenerInt)"
  }

widgetRemovedSignal :: (QStackedWidgetPtr object) => QtahSignal.Signal object (HoppyP.Int -> HoppyP.IO ())
widgetRemovedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerInt_new object' "2widgetRemoved(int)" fn'
    valid' <- listenerInt_isValid listener'
    if valid'
      then QtahP.fmap QtahP.Just $ QtahSignal.internalMakeConnection listener'
      else QtahFHR.delete listener' >> QtahP.return QtahP.Nothing
  , QtahSignal.internalName = "QStackedWidget::widgetRemoved (ListenerInt)"
  }
